/***************************************************************************
**
**  This file is part of max2curve.
**
**  This file may be distributed and/or modified under the terms of the
**  GNU General Public License version 2 or 3 as published by the Free
**  Software Foundation and appearing in the file LICENSE.GPL included
**  in the packaging of this file.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
**  more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**  See http://www.geopsy.org for more information.
**
**  Created : 2005-10-27
**  Authors:
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef FREQVELOCITYFILTER_H
#define FREQVELOCITYFILTER_H

#include <QGpGuiMath.h>

#include "ui_FreqVelocityFilter.h"

class FreqVelocityFilter : public Dialog, public Ui::FreqVelocityFilter
{
  Q_OBJECT
public:
  FreqVelocityFilter(QWidget *parent=0, Qt::WindowFlags f=Qt::WindowFlags());

  void setCurveList(const QList<CurvePropertiesWidget *>& list);
public slots:
  void enableWidgets();
};

#endif // FREQVELOCITYFILTER_H
